[PATCH] D26613: [ELF] - Allow symbols of STT_NOTYPE to be associated with SHT_SYMTAB sections.

George Rimar via llvm-commits llvm-commits at lists.llvm.org
Tue Nov 15 00:06:23 PST 2016


This revision was automatically updated to reflect the committed changes.
Closed by commit rL286939: [ELF] - Allow symbols of STT_NOTYPE to be associated with SHT_SYMTAB sections. (authored by grimar).

Changed prior to commit:
  https://reviews.llvm.org/D26613?vs=77814&id=77954#toc

Repository:
  rL LLVM

https://reviews.llvm.org/D26613

Files:
  lld/trunk/ELF/InputFiles.cpp
  lld/trunk/test/ELF/invalid/symtab-symbols.test


Index: lld/trunk/test/ELF/invalid/symtab-symbols.test
===================================================================
--- lld/trunk/test/ELF/invalid/symtab-symbols.test
+++ lld/trunk/test/ELF/invalid/symtab-symbols.test
@@ -0,0 +1,25 @@
+# RUN: yaml2obj %s -o %t
+# RUN: ld.lld -shared %t -o %tout
+
+# GNU assembler 2.17.50 [FreeBSD] 2007-07-03 could generate
+# broken objects.
+# Verify that lld can handle STT_NOTYPE symbols associated
+# with SHT_SYMTAB section. 
+
+!ELF
+FileHeader:
+  Class:           ELFCLASS64
+  Data:            ELFDATA2LSB
+  OSABI:           ELFOSABI_FREEBSD
+  Type:            ET_REL
+  Machine:         EM_X86_64
+Sections:
+  - Name:            .text
+    Type:            SHT_PROGBITS
+    Flags:           [ SHF_ALLOC, SHF_EXECINSTR ]
+    AddressAlign:    0x0000000000000010
+    Content:         "00000000"
+Symbols:
+  Local:
+    - Type:            STT_NOTYPE
+      Section:         .symtab
Index: lld/trunk/ELF/InputFiles.cpp
===================================================================
--- lld/trunk/ELF/InputFiles.cpp
+++ lld/trunk/ELF/InputFiles.cpp
@@ -417,13 +417,14 @@
     fatal(getFilename(this) + ": invalid section index: " + Twine(Index));
   InputSectionBase<ELFT> *S = Sections[Index];
 
   // We found that GNU assembler 2.17.50 [FreeBSD] 2007-07-03
   // could generate broken objects. STT_SECTION symbols can be
   // associated with SHT_REL[A]/SHT_SYMTAB/SHT_STRTAB sections.
-  // In this case it is fine for section to be null here as we
-  // do not allocate sections of these types.
+  // In this case it is fine for section to be null here as we do not
+  // allocate sections of these types.
   if (!S) {
-    if (Index == 0 || Sym.getType() == STT_SECTION)
+    if (Index == 0 || Sym.getType() == STT_SECTION ||
+        Sym.getType() == STT_NOTYPE)
       return nullptr;
     fatal(getFilename(this) + ": invalid section index: " + Twine(Index));
   }


-------------- next part --------------
@@ -417,13 +417,14 @@
   InputSectionBase<ELFT> *S = Sections[Index];
 
-  // We found that GNU assembler 2.17.50 [FreeBSD] 2007-07-03
-  // could generate broken objects. STT_SECTION symbols can be
+  // We found that GNU assembler 2.17.50 [FreeBSD] 2007-07-03 could
+  // generate broken objects. STT_SECTION/STT_NOTYPE symbols can be
   // associated with SHT_REL[A]/SHT_SYMTAB/SHT_STRTAB sections.
A non-text attachment was scrubbed...
Name: D26613.77954.patch
Type: text/x-patch
Size: 2070 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20161115/178c5a91/attachment.bin>


More information about the llvm-commits mailing list